Module task

Module task 

Structs

FutureTask
A combination of a task and a given future which implements Task based waking and polling.
Task
Minimal state used to represent a generic unit of execution used by the executors in the runtime.

Enums

Priority
The importance of a task which may be used to influence scheduling.

Functions

yield_now
Returns a future which can be used to yield the current future to the executor in order to let another task run.