Task

Struct Task 

pub struct Task { /* private fields */ }
Minimal state used to represent a generic unit of execution used by the executors in the runtime.

Implementations

Source

impl Task

pub fn new(priority: Priority, resume: unsafe fn(*mut Task)) -> Self

Create a new task with the given priority and resume function. The resume function is called when the thread is woken up by the scheduler internally to start executing its corresponding unit (not limited to futures).

pub fn next(&self) -> Option<NonNull<Self>>

Get the link provided by the task as it can function as a linked list node.

pub fn set_next(&mut self, next: Option<NonNull<Self>>)

Get the next task link having the task act as a linked list node.

pub fn set_priority(&mut self, priority: Priority)

Modify the runtime priority of the task. Should only be called before the task is resumed as the scheduler could also have ownership internally.

pub fn priority(&self) -> Priority

Get the assigned priority of the task.

pub fn resume(&mut self)

Call the resume function provided by [new] using the given task as a parameter.